@@ -5,7 +5,7 @@ from pydantic import BaseModel
 from pydantic_factories.factory import ModelFactory
 from pydantic_factories.fields import Ignore
 
-try:
+try:  # pragma: no cover
     from odmantic import EmbeddedModel, Model
 except ImportError:  # pragma: no cover
     Model = BaseModel
@@ -14,6 +14,8 @@ except ImportError:  # pragma: no cover
 
 T = TypeVar("T", Model, EmbeddedModel)
 
+# FIX: once odmantic updates to pydantic 1.9.0, uncomment the tests and return this to the dev dependencies
 
-class OdmanticModelFactory(ModelFactory[T]):
+
+class OdmanticModelFactory(ModelFactory[T]):  # pragma: no cover
     id = Ignore()
