@@ -6,13 +6,16 @@ from pydantic.fields import ModelField
 from pydantic_factories.factory import ModelFactory
 from pydantic_factories.utils import random
 
-try:
+try:  # pragma: no cover
     from ormar import Model
 except ImportError:  # pragma: no cover
     Model = BaseModel
 
 
-class OrmarModelFactory(ModelFactory[Model]):
+# FIX: once ormar updates to pydantic 1.9.0, uncomment the tests and return this to the dev dependencies
+
+
+class OrmarModelFactory(ModelFactory[Model]):  # pragma: no cover
     @classmethod
     def get_field_value(cls, model_field: ModelField) -> Any:
         """
