@@ -1,6 +1,7 @@
 import os
 from abc import ABC
-from collections import deque
+from collections import Counter, deque
+from contextlib import suppress
 from dataclasses import is_dataclass
 from datetime import date, datetime, time, timedelta
 from decimal import Decimal
@@ -117,10 +118,29 @@ from pydantic_factories.value_generators.primitives import (
     create_random_bytes,
 )
 
-T = TypeVar("T", BaseModel, DataclassProtocol)
+T = TypeVar("T", bound=Union[BaseModel, DataclassProtocol])
 
 default_faker = Faker()
 
+try:
+    # pydantic 1.9.0
+    from pydantic import (  # pylint: disable=ungrouped-imports
+        AmqpDsn,
+        ConstrainedFrozenSet,
+        FutureDate,
+        KafkaDsn,
+        PastDate,
+    )
+
+    is_latest_pydantic = True  # pylint: disable=invalid-name
+except ImportError:  # pragma: no cover
+    AmqpDsn = Any  # type: ignore
+    KafkaDsn = Any  # type: ignore
+    PastDate = Any  # type: ignore
+    FutureDate = Any  # type: ignore
+    ConstrainedFrozenSet = ConstrainedSet  # type: ignore
+    is_latest_pydantic = False  # pylint: disable=invalid-name
+
 
 class ModelFactory(ABC, Generic[T]):
     __model__: Type[T]
@@ -130,7 +150,7 @@ class ModelFactory(ABC, Generic[T]):
     __allow_none_optionals__: bool = True
 
     @classmethod
-    def seed_random(cls, seed: int):
+    def seed_random(cls, seed: int) -> None:
         """
         Seeds Fake and random methods with seed
         """
@@ -151,6 +171,7 @@ class ModelFactory(ABC, Generic[T]):
                 ConstrainedBytes,
                 ConstrainedDecimal,
                 ConstrainedFloat,
+                ConstrainedFrozenSet,
                 ConstrainedInt,
                 ConstrainedList,
                 ConstrainedSet,
@@ -176,7 +197,8 @@ class ModelFactory(ABC, Generic[T]):
             raise ConfigurationError("missing model class in factory Meta")
         model = cls.__model__
         if is_pydantic_model(model):
-            cast(BaseModel, model).update_forward_refs()
+            with suppress(NameError):
+                cast(BaseModel, model).update_forward_refs()
         return model
 
     @classmethod
@@ -225,7 +247,9 @@ class ModelFactory(ABC, Generic[T]):
         faker = cls._get_faker()
 
         return {
+            Any: lambda x: None,
             # primitives
+            object: object,
             float: faker.pyfloat,
             int: faker.pyint,
             bool: faker.pybool,
@@ -291,6 +315,11 @@ class ModelFactory(ABC, Generic[T]):
             IPvAnyAddress: faker.ipv4,
             IPvAnyInterface: faker.ipv4,
             IPvAnyNetwork: lambda: faker.ipv4(network=True),
+            AmqpDsn: lambda: "amqps://",
+            KafkaDsn: lambda: "kafka://",
+            PastDate: faker.past_date,
+            FutureDate: faker.future_date,
+            Counter: lambda: Counter(faker.pystr()),
         }
 
     @classmethod
@@ -302,6 +331,11 @@ class ModelFactory(ABC, Generic[T]):
         handler = cls.get_provider_map().get(field_type)
         if handler is not None:
             return handler()
+        if isclass(field_type):
+            # if value is a class we can try to naively instantiate it.
+            # this will work for classes that do not require any parameters passed to __init__
+            with suppress(Exception):
+                return field_type()
         raise ParameterError(
             f"Unsupported type: {repr(field_type)}"
             f"\n\nEither extend the providers map or add a factory function for this model field"
@@ -322,11 +356,16 @@ class ModelFactory(ABC, Generic[T]):
                 return handle_constrained_string(field=cast(ConstrainedStr, outer_type))
             if issubclass(outer_type, ConstrainedBytes):
                 return handle_constrained_bytes(field=cast(ConstrainedBytes, outer_type))
-            if issubclass(outer_type, ConstrainedSet) or issubclass(outer_type, ConstrainedList):
+            if issubclass(outer_type, (ConstrainedSet, ConstrainedList)) or (
+                is_latest_pydantic and issubclass(outer_type, ConstrainedFrozenSet)
+            ):
                 collection_type = list if issubclass(outer_type, ConstrainedList) else set
-                return handle_constrained_collection(
+                result = handle_constrained_collection(
                     collection_type=collection_type, model_field=model_field, model_factory=cls  # type: ignore
                 )
+                if is_latest_pydantic and issubclass(outer_type, ConstrainedFrozenSet):  # pragma: no cover
+                    return frozenset(*result)
+                return result
             raise ParameterError(f"Unknown constrained field: {outer_type.__name__}")  # pragma: no cover
         except AssertionError as e:  # pragma: no cover
             raise ParameterError from e
@@ -355,7 +394,7 @@ class ModelFactory(ABC, Generic[T]):
         cls,
         model: Type[BaseModel],
         base: Optional[Type["ModelFactory"]] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> "ModelFactory":  # pragma: no cover
         """Dynamically generates a factory given a model"""
 
@@ -367,14 +406,16 @@ class ModelFactory(ABC, Generic[T]):
             ModelFactory,
             type(
                 f"{model.__name__}Factory",
-                (base or ModelFactory,),
+                (base or cls,),
                 {"__model__": model, **kwargs},
             ),
         )
 
     @classmethod
     def get_field_value(cls, model_field: ModelField) -> Any:
-        """Returns a field value on the sub-class if existing, otherwise returns a mock value"""
+        """
+        Returns a field value on the subclass if existing, otherwise returns a mock value
+        """
         if model_field.field_info.const:
             return model_field.get_default()
         if cls.should_set_none_value(model_field=model_field):
@@ -408,7 +449,7 @@ class ModelFactory(ABC, Generic[T]):
         return False
 
     @classmethod
-    def should_set_field_value(cls, field_name: str, **kwargs) -> bool:
+    def should_set_field_value(cls, field_name: str, **kwargs: Any) -> bool:
         """
         Ascertain whether to set a value for a given field_name
 
@@ -435,7 +476,7 @@ class ModelFactory(ABC, Generic[T]):
         return model.__fields__.items()  # type: ignore
 
     @classmethod
-    def build(cls, factory_use_construct: bool = False, **kwargs) -> T:
+    def build(cls, factory_use_construct: bool = False, **kwargs: Any) -> T:
         """
         builds an instance of the factory's __model__
 
@@ -456,36 +497,36 @@ class ModelFactory(ABC, Generic[T]):
             if is_pydantic_model(cls.__model__):
                 return cls.__model__.construct(**kwargs)  # type: ignore
             raise ConfigurationError("factory_use_construct requires a pydantic model as the factory's __model__")
-        return cls.__model__(**kwargs)
+        return cast(T, cls.__model__(**kwargs))
 
     @classmethod
-    def batch(cls, size: int, **kwargs) -> List[T]:
+    def batch(cls, size: int, **kwargs: Any) -> List[T]:
         """builds a batch of size n of the factory's Meta.model"""
         return [cls.build(**kwargs) for _ in range(size)]
 
     @classmethod
-    def create_sync(cls, **kwargs) -> T:
+    def create_sync(cls, **kwargs: Any) -> T:
         """Build and persist a single model instance synchronously"""
         sync_persistence_handler = cls._get_sync_persistence()
         instance = cls.build(**kwargs)
         return sync_persistence_handler.save(data=instance)
 
     @classmethod
-    def create_batch_sync(cls, size: int, **kwargs) -> List[T]:
+    def create_batch_sync(cls, size: int, **kwargs: Any) -> List[T]:
         """Build and persist a batch of n size model instances synchronously"""
         sync_persistence_handler = cls._get_sync_persistence()
         batch = cls.batch(size, **kwargs)
         return sync_persistence_handler.save_many(data=batch)
 
     @classmethod
-    async def create_async(cls, **kwargs) -> T:
+    async def create_async(cls, **kwargs: Any) -> T:
         """Build and persist a single model instance asynchronously"""
         async_persistence_handler = cls._get_async_persistence()
         instance = cls.build(**kwargs)
         return await async_persistence_handler.save(data=instance)
 
     @classmethod
-    async def create_batch_async(cls, size: int, **kwargs) -> List[T]:
+    async def create_batch_async(cls, size: int, **kwargs: Any) -> List[T]:
         """Build and persist a batch of n size model instances asynchronously"""
         async_persistence_handler = cls._get_async_persistence()
         batch = cls.batch(size, **kwargs)
