@@ -7,7 +7,7 @@ class Use:
     The callback will be invoked whenever building the given factory attribute.
     """
 
-    def __init__(self, cb: Callable, *args, **defaults):
+    def __init__(self, cb: Callable, *args: Any, **defaults: Any) -> None:
         self.cb = cb
         self.defaults = defaults
         self.args = args
